# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExportWorkflowChild(Model):
    """Represents workflow settings for bill export.

    All required parameters must be populated in order to send to Azure.

    :param export_mode_enabled: Required. Whether or not Export Mode is
     enabled <span class='property-internal'>Required</span>
    :type export_mode_enabled: bool
    :param can_export: Required. The point at which a bill is eligible for
     export <span class='property-internal'>Required</span> <span
     class='property-internal'>One of never, after entry, after batch, after
     approval, after batch approval </span>
    :type can_export: str
    :param include_udfs: Required. Whether or not custom fields should be
     included in export <span class='property-internal'>Required</span>
    :type include_udfs: bool
    """

    _validation = {
        'export_mode_enabled': {'required': True},
        'can_export': {'required': True},
        'include_udfs': {'required': True},
    }

    _attribute_map = {
        'export_mode_enabled': {'key': 'exportModeEnabled', 'type': 'bool'},
        'can_export': {'key': 'canExport', 'type': 'str'},
        'include_udfs': {'key': 'includeUdfs', 'type': 'bool'},
    }

    def __init__(self, *, export_mode_enabled: bool, can_export: str, include_udfs: bool, **kwargs) -> None:
        super(ExportWorkflowChild, self).__init__(**kwargs)
        self.export_mode_enabled = export_mode_enabled
        self.can_export = can_export
        self.include_udfs = include_udfs



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillPaymentDetailsFileResponse(Model):
    """BillPaymentDetailsFileResponse.

    :param success: Number of successful bill payment detail updates <span
     class='property-internal'>Required (defined)</span>
    :type success: int
    :param failure: Number of unsuccessful bill payment detail updates <span
     class='property-internal'>Required (defined)</span>
    :type failure: int
    :param kickout_stream: Base64 encoded File content of unsuccessful bill
     payment detail updates with reasons for failure <span
     class='property-internal'>Required (defined)</span>
    :type kickout_stream: str
    """

    _attribute_map = {
        'success': {'key': 'success', 'type': 'int'},
        'failure': {'key': 'failure', 'type': 'int'},
        'kickout_stream': {'key': 'kickoutStream', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BillPaymentDetailsFileResponse, self).__init__(**kwargs)
        self.success = kwargs.get('success', None)
        self.failure = kwargs.get('failure', None)
        self.kickout_stream = kwargs.get('kickout_stream', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowDigestChild(Model):
    """This class inherits all of the billing period summary properties for a
    source meter
    and adds a list of billing period summaries for each bill split destination
    meter.

    :param splits: List of billing period summaries for meters that are
     children of a bill split source meter.
     This list will be null for calculated source meters.
    :type splits:
     list[~energycap.sdk.models.ChargebackWorkflowDigestSplitChild]
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param current_period:
    :type current_period: ~energycap.sdk.models.BillingPeriodUseCostChild
    :param prior_period:
    :type prior_period: ~energycap.sdk.models.BillingPeriodUseCostDeltaChild
    :param prior_year:
    :type prior_year: ~energycap.sdk.models.BillingPeriodUseCostDeltaChild
    """

    _attribute_map = {
        'splits': {'key': 'splits', 'type': '[ChargebackWorkflowDigestSplitChild]'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'current_period': {'key': 'currentPeriod', 'type': 'BillingPeriodUseCostChild'},
        'prior_period': {'key': 'priorPeriod', 'type': 'BillingPeriodUseCostDeltaChild'},
        'prior_year': {'key': 'priorYear', 'type': 'BillingPeriodUseCostDeltaChild'},
    }

    def __init__(self, *, splits=None, meter=None, current_period=None, prior_period=None, prior_year=None, **kwargs) -> None:
        super(ChargebackWorkflowDigestChild, self).__init__(**kwargs)
        self.splits = splits
        self.meter = meter
        self.current_period = current_period
        self.prior_period = prior_period
        self.prior_year = prior_year



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalendarizedCalculationResponse(Model):
    """Adding calendarized calculation involving meters.

    :param calendarized_sum: Addition calculation involving meters
    :type calendarized_sum: list[~energycap.sdk.models.MeterChild]
    """

    _attribute_map = {
        'calendarized_sum': {'key': 'calendarizedSum', 'type': '[MeterChild]'},
    }

    def __init__(self, *, calendarized_sum=None, **kwargs) -> None:
        super(CalendarizedCalculationResponse, self).__init__(**kwargs)
        self.calendarized_sum = calendarized_sum



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingsObservation(Model):
    """ReadingsObservation.

    :param observation_id: The unique ID for the reading <span
     class='property-internal'>Required (defined)</span>
    :type observation_id: long
    :param time: The date and time of the reading <span
     class='property-internal'>Required (defined)</span>
    :type time: datetime
    :param value: The raw or computed value of the reading <span
     class='property-internal'>Required (defined)</span>
    :type value: float
    :param raw_value: The raw value of the reading (before multiplier or delta
     are applied) <span class='property-internal'>Required (defined)</span>
    :type raw_value: float
    :param estimated: Indicates if the reading is estimated <span
     class='property-internal'>Required (defined)</span>
    :type estimated: bool
    :param note: A note pertaining to the reading <span
     class='property-internal'>Required (defined)</span>
    :type note: str
    """

    _attribute_map = {
        'observation_id': {'key': 'observationId', 'type': 'long'},
        'time': {'key': 'time', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'raw_value': {'key': 'rawValue', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReadingsObservation, self).__init__(**kwargs)
        self.observation_id = kwargs.get('observation_id', None)
        self.time = kwargs.get('time', None)
        self.value = kwargs.get('value', None)
        self.raw_value = kwargs.get('raw_value', None)
        self.estimated = kwargs.get('estimated', None)
        self.note = kwargs.get('note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionChild(Model):
    """ReportDistributionChild.

    :param report_distribution_id: The id of the report distribution
    :type report_distribution_id: int
    :param report_distribution_name: The name of the report distribution
    :type report_distribution_name: str
    :param report_code: The report code to run as part of the report
     distribution
    :type report_code: str
    :param created_by_user:
    :type created_by_user: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'report_distribution_id': {'key': 'reportDistributionId', 'type': 'int'},
        'report_distribution_name': {'key': 'reportDistributionName', 'type': 'str'},
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'created_by_user': {'key': 'createdByUser', 'type': 'UserChild'},
    }

    def __init__(self, **kwargs):
        super(ReportDistributionChild, self).__init__(**kwargs)
        self.report_distribution_id = kwargs.get('report_distribution_id', None)
        self.report_distribution_name = kwargs.get('report_distribution_name', None)
        self.report_code = kwargs.get('report_code', None)
        self.created_by_user = kwargs.get('created_by_user', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAccountMeterStatisticsResponse(Model):
    """BillAccountMeterStatisticsResponse.

    :param use_per_day:
    :type use_per_day: ~energycap.sdk.models.StatisticsResponse
    :param cost_per_day:
    :type cost_per_day: ~energycap.sdk.models.StatisticsResponse
    :param demand_per_day:
    :type demand_per_day: ~energycap.sdk.models.StatisticsResponse
    :param bill_id: The bill identifier
    :type bill_id: int
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param days: The number of days the bill covers
    :type days: int
    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    """

    _attribute_map = {
        'use_per_day': {'key': 'usePerDay', 'type': 'StatisticsResponse'},
        'cost_per_day': {'key': 'costPerDay', 'type': 'StatisticsResponse'},
        'demand_per_day': {'key': 'demandPerDay', 'type': 'StatisticsResponse'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'days': {'key': 'days', 'type': 'int'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
    }

    def __init__(self, *, use_per_day=None, cost_per_day=None, demand_per_day=None, bill_id: int=None, billing_period: int=None, begin_date=None, end_date=None, days: int=None, account=None, meter=None, **kwargs) -> None:
        super(BillAccountMeterStatisticsResponse, self).__init__(**kwargs)
        self.use_per_day = use_per_day
        self.cost_per_day = cost_per_day
        self.demand_per_day = demand_per_day
        self.bill_id = bill_id
        self.billing_period = billing_period
        self.begin_date = begin_date
        self.end_date = end_date
        self.days = days
        self.account = account
        self.meter = meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryMeterChild(Model):
    """BillEntryMeterChild.

    :param from_template: True means a "template" was used to generate the
     bodylines
     False means an existing bill was used to generate the bodylines
    :type from_template: bool
    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter name
    :type meter_info: str
    :param general_ledger_code: The meter gl code
    :type general_ledger_code: str
    :param body_lines: The bill's meter-level details
    :type body_lines: list[~energycap.sdk.models.BillEntryBodyLine]
    """

    _attribute_map = {
        'from_template': {'key': 'fromTemplate', 'type': 'bool'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'body_lines': {'key': 'bodyLines', 'type': '[BillEntryBodyLine]'},
    }

    def __init__(self, **kwargs):
        super(BillEntryMeterChild, self).__init__(**kwargs)
        self.from_template = kwargs.get('from_template', None)
        self.meter_id = kwargs.get('meter_id', None)
        self.meter_code = kwargs.get('meter_code', None)
        self.meter_info = kwargs.get('meter_info', None)
        self.general_ledger_code = kwargs.get('general_ledger_code', None)
        self.body_lines = kwargs.get('body_lines', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Country(Model):
    """Country.

    :param country_id:
    :type country_id: int
    :param name:
    :type name: str
    :param alpha2_code:
    :type alpha2_code: str
    :param possible_spellings:
    :type possible_spellings: list[str]
    """

    _attribute_map = {
        'country_id': {'key': 'countryId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'alpha2_code': {'key': 'alpha2Code', 'type': 'str'},
        'possible_spellings': {'key': 'possibleSpellings', 'type': '[str]'},
    }

    def __init__(self, *, country_id: int=None, name: str=None, alpha2_code: str=None, possible_spellings=None, **kwargs) -> None:
        super(Country, self).__init__(**kwargs)
        self.country_id = country_id
        self.name = name
        self.alpha2_code = alpha2_code
        self.possible_spellings = possible_spellings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchChild(Model):
    """BatchChild.

    :param batch_id: The batch id.
    :type batch_id: int
    :param batch_code: The batch code.
    :type batch_code: str
    """

    _attribute_map = {
        'batch_id': {'key': 'batchId', 'type': 'int'},
        'batch_code': {'key': 'batchCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BatchChild, self).__init__(**kwargs)
        self.batch_id = kwargs.get('batch_id', None)
        self.batch_code = kwargs.get('batch_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchMeterChildSearchMeterChild(Model):
    """SearchMeterChildSearchMeterChild.

    All required parameters must be populated in order to send to Azure.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: Required. The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: Required. The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param accounts: The collection of accounts
    :type accounts: list[~energycap.sdk.models.MeterAccountChild]
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param meter_type:
    :type meter_type: ~energycap.sdk.models.MeterTypeChild
    :param postal_code: The address postal code
    :type postal_code: str
    :param city: The address city
    :type city: str
    :param state: The address state
    :type state: str
    :param country: The address country
    :type country: str
    :param line1: The address first line
    :type line1: str
    :param line2: The address second line
    :type line2: str
    :param line3: The address third line
    :type line3: str
    :param bill_entry_note: The bill entry note
    :type bill_entry_note: str
    :param include_in_energy_star: Indicates if the building is included in
     ENERGY STAR submissions
    :type include_in_energy_star: bool
    :param properties: An array of meter properties
    :type properties: dict[str, str]
    :param parent_path: The collection of places representing the path to its
     parent
    :type parent_path: list[~energycap.sdk.models.SearchParentPlaceChild]
    :param active: Indicates whether the meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the meter is a child of a
     split
    :type is_split_child_meter: bool
    :param previous_serial_number: The previous serial number of the meter
    :type previous_serial_number: str
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'accounts': {'key': 'accounts', 'type': '[MeterAccountChild]'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'meter_type': {'key': 'meterType', 'type': 'MeterTypeChild'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'parent_path': {'key': 'parentPath', 'type': '[SearchParentPlaceChild]'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
        'previous_serial_number': {'key': 'previousSerialNumber', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SearchMeterChildSearchMeterChild, self).__init__(**kwargs)
        self.meter_id = kwargs.get('meter_id', None)
        self.meter_code = kwargs.get('meter_code', None)
        self.meter_info = kwargs.get('meter_info', None)
        self.accounts = kwargs.get('accounts', None)
        self.commodity = kwargs.get('commodity', None)
        self.meter_type = kwargs.get('meter_type', None)
        self.postal_code = kwargs.get('postal_code', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
        self.line1 = kwargs.get('line1', None)
        self.line2 = kwargs.get('line2', None)
        self.line3 = kwargs.get('line3', None)
        self.bill_entry_note = kwargs.get('bill_entry_note', None)
        self.include_in_energy_star = kwargs.get('include_in_energy_star', None)
        self.properties = kwargs.get('properties', None)
        self.parent_path = kwargs.get('parent_path', None)
        self.active = kwargs.get('active', None)
        self.is_calculated_meter = kwargs.get('is_calculated_meter', None)
        self.is_split_parent_meter = kwargs.get('is_split_parent_meter', None)
        self.is_split_child_meter = kwargs.get('is_split_child_meter', None)
        self.previous_serial_number = kwargs.get('previous_serial_number', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationRule(Model):
    """ObservationRule.

    :param observation_rule_id: The observation rule identifier
    :type observation_rule_id: int
    :param observation_rule_code: The observation rule code
    :type observation_rule_code: str
    :param observation_rule_info: The observation rule info
    :type observation_rule_info: str
    """

    _attribute_map = {
        'observation_rule_id': {'key': 'observationRuleId', 'type': 'int'},
        'observation_rule_code': {'key': 'observationRuleCode', 'type': 'str'},
        'observation_rule_info': {'key': 'observationRuleInfo', 'type': 'str'},
    }

    def __init__(self, *, observation_rule_id: int=None, observation_rule_code: str=None, observation_rule_info: str=None, **kwargs) -> None:
        super(ObservationRule, self).__init__(**kwargs)
        self.observation_rule_id = observation_rule_id
        self.observation_rule_code = observation_rule_code
        self.observation_rule_info = observation_rule_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuditSettingResponse(Model):
    """AuditSettingResponse.

    :param setting_status: The status of the audit setting - Possible values
     Check, Hold, Skip
    :type setting_status: str
    :param setting_code: The setting code
    :type setting_code: str
    :param setting_description: A description of the setting
    :type setting_description: str
    :param minimum_cost: Minimum Bill/Meter Cost.
     This audit wwill run only when the cost meets the specified minimum cost
    :type minimum_cost: int
    :param assignees: List of Assignees.
     UserChildDTO representing the users the flag should get assigned to when
     the audit fails.
    :type assignees: list[~energycap.sdk.models.UserChild]
    """

    _attribute_map = {
        'setting_status': {'key': 'settingStatus', 'type': 'str'},
        'setting_code': {'key': 'settingCode', 'type': 'str'},
        'setting_description': {'key': 'settingDescription', 'type': 'str'},
        'minimum_cost': {'key': 'minimumCost', 'type': 'int'},
        'assignees': {'key': 'assignees', 'type': '[UserChild]'},
    }

    def __init__(self, *, setting_status: str=None, setting_code: str=None, setting_description: str=None, minimum_cost: int=None, assignees=None, **kwargs) -> None:
        super(AuditSettingResponse, self).__init__(**kwargs)
        self.setting_status = setting_status
        self.setting_code = setting_code
        self.setting_description = setting_description
        self.minimum_cost = minimum_cost
        self.assignees = assignees



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Reading(Model):
    """Reading.

    All required parameters must be populated in order to send to Azure.

    :param time: Required. The date and time of the reading <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type time: datetime
    :param value: Required. The reading's value <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type value: float
    :param estimated: Indicates if the reading is estimated <span
     class='property-internal'>Required (defined)</span>
    :type estimated: bool
    :param note: A note pertaining to the reading <span
     class='property-internal'>Required (defined)</span>
    :type note: str
    """

    _validation = {
        'time': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'time': {'key': 'time', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(Reading, self).__init__(**kwargs)
        self.time = kwargs.get('time', None)
        self.value = kwargs.get('value', None)
        self.estimated = kwargs.get('estimated', None)
        self.note = kwargs.get('note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelLatestReading(Model):
    """ChannelLatestReading.

    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChildBase
    :param last_reading:
    :type last_reading: ~energycap.sdk.models.ReadingChildBase
    :param channel_id: The channel identifier
    :type channel_id: int
    :param interval: The channel interval in seconds.
     Monthly = 2592000
     Weekly = 604800
     Daily = 86400
     Hourly = 3600
     Thirty_Minutes = 1800
     Fifteen_Minutes = 900
    :type interval: int
    """

    _attribute_map = {
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChildBase'},
        'last_reading': {'key': 'lastReading', 'type': 'ReadingChildBase'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, *, observation_type=None, last_reading=None, channel_id: int=None, interval: int=None, **kwargs) -> None:
        super(ChannelLatestReading, self).__init__(**kwargs)
        self.observation_type = observation_type
        self.last_reading = last_reading
        self.channel_id = channel_id
        self.interval = interval



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AddressLookup(Model):
    """AddressLookup.

    :param address_type_id:
    :type address_type_id: int
    :param line1:
    :type line1: str
    :param line2:
    :type line2: str
    :param line3:
    :type line3: str
    :param city:
    :type city: str
    :param state:
    :type state: str
    :param country:
    :type country: str
    :param postal_code:
    :type postal_code: str
    :param latitude:
    :type latitude: float
    :param longitude:
    :type longitude: float
    :param unique_location_identifier:
    :type unique_location_identifier: str
    :param location_properties:
    :type location_properties: dict[str, object]
    """

    _attribute_map = {
        'address_type_id': {'key': 'addressTypeId', 'type': 'int'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'unique_location_identifier': {'key': 'uniqueLocationIdentifier', 'type': 'str'},
        'location_properties': {'key': 'locationProperties', 'type': '{object}'},
    }

    def __init__(self, **kwargs):
        super(AddressLookup, self).__init__(**kwargs)
        self.address_type_id = kwargs.get('address_type_id', None)
        self.line1 = kwargs.get('line1', None)
        self.line2 = kwargs.get('line2', None)
        self.line3 = kwargs.get('line3', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
        self.postal_code = kwargs.get('postal_code', None)
        self.latitude = kwargs.get('latitude', None)
        self.longitude = kwargs.get('longitude', None)
        self.unique_location_identifier = kwargs.get('unique_location_identifier', None)
        self.location_properties = kwargs.get('location_properties', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupMember(Model):
    """MeterGroupMember.

    :param meter_group_id: The meter group this meter will belong to <span
     class='property-internal'>Required (defined)</span>
    :type meter_group_id: int
    :param include_in_charts: Whether to include this meter in the group's
     benchmark charts <span class='property-internal'>Required (defined)</span>
    :type include_in_charts: bool
    """

    _attribute_map = {
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(MeterGroupMember, self).__init__(**kwargs)
        self.meter_group_id = kwargs.get('meter_group_id', None)
        self.include_in_charts = kwargs.get('include_in_charts', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupDigestWeatherRankingChild(Model):
    """PlaceGroupDigestWeatherRankingChild.

    :param base_value:
    :type base_value: float
    :param slope_value:
    :type slope_value: float
    :param place_id:
    :type place_id: int
    :param place_code:
    :type place_code: str
    :param place_info:
    :type place_info: str
    :param place_display:
    :type place_display: str
    :param include_in_charts:
    :type include_in_charts: bool
    """

    _attribute_map = {
        'base_value': {'key': 'baseValue', 'type': 'float'},
        'slope_value': {'key': 'slopeValue', 'type': 'float'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_display': {'key': 'placeDisplay', 'type': 'str'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(PlaceGroupDigestWeatherRankingChild, self).__init__(**kwargs)
        self.base_value = kwargs.get('base_value', None)
        self.slope_value = kwargs.get('slope_value', None)
        self.place_id = kwargs.get('place_id', None)
        self.place_code = kwargs.get('place_code', None)
        self.place_info = kwargs.get('place_info', None)
        self.place_display = kwargs.get('place_display', None)
        self.include_in_charts = kwargs.get('include_in_charts', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterAccountChild(Model):
    """MeterAccountChild.

    :param account_meter_id: The MeterAccount meter identifier
    :type account_meter_id: int
    :param account_id: The MeterAccount identifier for this MeterAccount meter
    :type account_id: int
    :param account_code: The code of the MeterAccount for this MeterAccount
     meter
    :type account_code: str
    :param account_info: The info of the MeterAccount for this MeterAccount
     meter
    :type account_info: str
    :param active: Indicates whether the Account is active or inactive
    :type active: bool
    :param has_calculated_meter: Indicates whether the Account has a child
     calculated meter
    :type has_calculated_meter: bool
    :param has_split_parent_meter: Indicates whether the Account is a
     recipient of a split
    :type has_split_parent_meter: bool
    :param has_split_child_meter: Indicates whether the Account has a child
     split meter
    :type has_split_child_meter: bool
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param meter_general_ledger:
    :type meter_general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    :param account_general_ledger:
    :type account_general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    :param vendor_type:
    :type vendor_type: ~energycap.sdk.models.VendorTypeChild
    :param start_date: The beginning date and time for this MeterAccount meter
     relationship
    :type start_date: datetime
    :param end_date: The ending date and time for this MeterAccount meter
     relationship
    :type end_date: datetime
    :param data_access_release_id: The data access release identifier for this
     MeterAccount meter relationship, null if there is no release
    :type data_access_release_id: int
    """

    _attribute_map = {
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'active': {'key': 'active', 'type': 'bool'},
        'has_calculated_meter': {'key': 'hasCalculatedMeter', 'type': 'bool'},
        'has_split_parent_meter': {'key': 'hasSplitParentMeter', 'type': 'bool'},
        'has_split_child_meter': {'key': 'hasSplitChildMeter', 'type': 'bool'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'meter_general_ledger': {'key': 'meterGeneralLedger', 'type': 'GeneralLedgerChild'},
        'account_general_ledger': {'key': 'accountGeneralLedger', 'type': 'GeneralLedgerChild'},
        'vendor_type': {'key': 'vendorType', 'type': 'VendorTypeChild'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'data_access_release_id': {'key': 'dataAccessReleaseId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(MeterAccountChild, self).__init__(**kwargs)
        self.account_meter_id = kwargs.get('account_meter_id', None)
        self.account_id = kwargs.get('account_id', None)
        self.account_code = kwargs.get('account_code', None)
        self.account_info = kwargs.get('account_info', None)
        self.active = kwargs.get('active', None)
        self.has_calculated_meter = kwargs.get('has_calculated_meter', None)
        self.has_split_parent_meter = kwargs.get('has_split_parent_meter', None)
        self.has_split_child_meter = kwargs.get('has_split_child_meter', None)
        self.vendor = kwargs.get('vendor', None)
        self.meter_general_ledger = kwargs.get('meter_general_ledger', None)
        self.account_general_ledger = kwargs.get('account_general_ledger', None)
        self.vendor_type = kwargs.get('vendor_type', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.data_access_release_id = kwargs.get('data_access_release_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationType(Model):
    """ObservationType.

    :param observation_type_id:
    :type observation_type_id: int
    :param credit:
    :type credit: int
    :param time_of_use:
    :type time_of_use: int
    :param creation:
    :type creation: int
    :param noun:
    :type noun: int
    :param observation_type_code:  <span class='property-internal'>Must be
     between 0 and 16 characters</span>
    :type observation_type_code: str
    :param observation_type_info:  <span class='property-internal'>Must be
     between 0 and 32 characters</span>
    :type observation_type_info: str
    """

    _validation = {
        'observation_type_code': {'max_length': 16, 'min_length': 0},
        'observation_type_info': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'credit': {'key': 'credit', 'type': 'int'},
        'time_of_use': {'key': 'timeOfUse', 'type': 'int'},
        'creation': {'key': 'creation', 'type': 'int'},
        'noun': {'key': 'noun', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_type_info': {'key': 'observationTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, observation_type_id: int=None, credit: int=None, time_of_use: int=None, creation: int=None, noun: int=None, observation_type_code: str=None, observation_type_info: str=None, **kwargs) -> None:
        super(ObservationType, self).__init__(**kwargs)
        self.observation_type_id = observation_type_id
        self.credit = credit
        self.time_of_use = time_of_use
        self.creation = creation
        self.noun = noun
        self.observation_type_code = observation_type_code
        self.observation_type_info = observation_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseStatus(Model):
    """DataAccessReleaseStatus.

    :param data_access_release_status_id: Id of the Data Access Release Status
     Possible values are:
     1 - Not Applicable
     2 - Required
     3 - Pending
     4 - Released
    :type data_access_release_status_id: int
    :param data_access_release_status_info: Data Access Release Status
     Information
     Possible values are:
     Not Applicable
     Required
     Pending
     Released
    :type data_access_release_status_info: str
    """

    _attribute_map = {
        'data_access_release_status_id': {'key': 'dataAccessReleaseStatusId', 'type': 'int'},
        'data_access_release_status_info': {'key': 'dataAccessReleaseStatusInfo', 'type': 'str'},
    }

    def __init__(self, *, data_access_release_status_id: int=None, data_access_release_status_info: str=None, **kwargs) -> None:
        super(DataAccessReleaseStatus, self).__init__(**kwargs)
        self.data_access_release_status_id = data_access_release_status_id
        self.data_access_release_status_info = data_access_release_status_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountAlertRequest(Model):
    """AccountAlertRequest.

    All required parameters must be populated in order to send to Azure.

    :param begin_date: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type begin_date: datetime
    :param end_date: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type end_date: datetime
    :param message: Required.  <span class='property-internal'>Required</span>
    :type message: str
    :param allow_bill_processing: Required.  <span
     class='property-internal'>Required</span>
    :type allow_bill_processing: bool
    """

    _validation = {
        'begin_date': {'required': True},
        'end_date': {'required': True},
        'message': {'required': True},
        'allow_bill_processing': {'required': True},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'message': {'key': 'message', 'type': 'str'},
        'allow_bill_processing': {'key': 'allowBillProcessing', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AccountAlertRequest, self).__init__(**kwargs)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.message = kwargs.get('message', None)
        self.allow_bill_processing = kwargs.get('allow_bill_processing', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackTaskVersionResponse(Model):
    """ChargebackTaskVersionResponse.

    :param version_id: The specific version id within the task we are
     reporting on
    :type version_id: int
    :param number_of_bills_created: The number of bills created for this
     version within the task
    :type number_of_bills_created: int
    :param error_message: Error that may have occurred when running this
     version within the task
    :type error_message: str
    :param destination_bill_ids: The billids of all the destination bills
     created by this version within the task
    :type destination_bill_ids: list[int]
    :param source_bill_id: If this was a bill split task, then ID of the bill
     that was split by this version within the task
    :type source_bill_id: int
    :param task_id: Identifier for the task
    :type task_id: int
    :param workflow:
    :type workflow: ~energycap.sdk.models.ChargebackWorkflowStepChild
    :param task_begin: Begin date when the task started
    :type task_begin: datetime
    :param task_end: End date when the task ended
    :type task_end: datetime
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param billing_period: The billing period the task was run for
    :type billing_period: int
    :param batch:
    :type batch: ~energycap.sdk.models.BatchChild
    :param settings: The task's settings
    :type settings: object
    :param comment: User comments on the task
    :type comment: str
    :param status: Current status of the task
    :type status: str
    :param chargeback_type: The chargeback type.  Either "Split" or
     "Calculation"
    :type chargeback_type: str
    :param reversed_by:
    :type reversed_by: ~energycap.sdk.models.UserChild
    :param reversed_date: The date when all bills generated by the task were
     voided or deleted
    :type reversed_date: datetime
    :param number_of_analyzing_bills: The number of bills that are currently
     analyzing within the task
    :type number_of_analyzing_bills: int
    :param number_of_unresolved_flags: The number of unresolved flags on bills
     within the task
    :type number_of_unresolved_flags: int
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'number_of_bills_created': {'key': 'numberOfBillsCreated', 'type': 'int'},
        'error_message': {'key': 'errorMessage', 'type': 'str'},
        'destination_bill_ids': {'key': 'destinationBillIds', 'type': '[int]'},
        'source_bill_id': {'key': 'sourceBillId', 'type': 'int'},
        'task_id': {'key': 'taskId', 'type': 'int'},
        'workflow': {'key': 'workflow', 'type': 'ChargebackWorkflowStepChild'},
        'task_begin': {'key': 'taskBegin', 'type': 'iso-8601'},
        'task_end': {'key': 'taskEnd', 'type': 'iso-8601'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'batch': {'key': 'batch', 'type': 'BatchChild'},
        'settings': {'key': 'settings', 'type': 'object'},
        'comment': {'key': 'comment', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'chargeback_type': {'key': 'chargebackType', 'type': 'str'},
        'reversed_by': {'key': 'reversedBy', 'type': 'UserChild'},
        'reversed_date': {'key': 'reversedDate', 'type': 'iso-8601'},
        'number_of_analyzing_bills': {'key': 'numberOfAnalyzingBills', 'type': 'int'},
        'number_of_unresolved_flags': {'key': 'numberOfUnresolvedFlags', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ChargebackTaskVersionResponse, self).__init__(**kwargs)
        self.version_id = kwargs.get('version_id', None)
        self.number_of_bills_created = kwargs.get('number_of_bills_created', None)
        self.error_message = kwargs.get('error_message', None)
        self.destination_bill_ids = kwargs.get('destination_bill_ids', None)
        self.source_bill_id = kwargs.get('source_bill_id', None)
        self.task_id = kwargs.get('task_id', None)
        self.workflow = kwargs.get('workflow', None)
        self.task_begin = kwargs.get('task_begin', None)
        self.task_end = kwargs.get('task_end', None)
        self.user = kwargs.get('user', None)
        self.billing_period = kwargs.get('billing_period', None)
        self.batch = kwargs.get('batch', None)
        self.settings = kwargs.get('settings', None)
        self.comment = kwargs.get('comment', None)
        self.status = kwargs.get('status', None)
        self.chargeback_type = kwargs.get('chargeback_type', None)
        self.reversed_by = kwargs.get('reversed_by', None)
        self.reversed_date = kwargs.get('reversed_date', None)
        self.number_of_analyzing_bills = kwargs.get('number_of_analyzing_bills', None)
        self.number_of_unresolved_flags = kwargs.get('number_of_unresolved_flags', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestActualAndCalendarizedYearlyResponseResults(Model):
    """MeterDigestActualAndCalendarizedYearlyResponseResults.

    :param year: Year
    :type year: str
    :param total_cost: Total Cost
    :type total_cost: float
    :param native_use: Native Use
    :type native_use: float
    :param native_use_unit_cost: Native Use Unit Cost
    :type native_use_unit_cost: float
    :param common_use: Common Use
    :type common_use: float
    :param common_use_unit_cost: Common Use Unit Cost
    :type common_use_unit_cost: float
    :param native_demand: Native Demand
    :type native_demand: float
    :param native_demand_unit_cost: Native Demand Unit Cost
    :type native_demand_unit_cost: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'native_use_unit_cost': {'key': 'nativeUseUnitCost', 'type': 'float'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'common_use_unit_cost': {'key': 'commonUseUnitCost', 'type': 'float'},
        'native_demand': {'key': 'nativeDemand', 'type': 'float'},
        'native_demand_unit_cost': {'key': 'nativeDemandUnitCost', 'type': 'float'},
    }

    def __init__(self, *, year: str=None, total_cost: float=None, native_use: float=None, native_use_unit_cost: float=None, common_use: float=None, common_use_unit_cost: float=None, native_demand: float=None, native_demand_unit_cost: float=None, **kwargs) -> None:
        super(MeterDigestActualAndCalendarizedYearlyResponseResults, self).__init__(**kwargs)
        self.year = year
        self.total_cost = total_cost
        self.native_use = native_use
        self.native_use_unit_cost = native_use_unit_cost
        self.common_use = common_use
        self.common_use_unit_cost = common_use_unit_cost
        self.native_demand = native_demand
        self.native_demand_unit_cost = native_demand_unit_cost



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebacksModuleClassPermission(Model):
    """ChargebacksModuleClassPermission.

    :param view:
    :type view: bool
    """

    _attribute_map = {
        'view': {'key': 'view', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ChargebacksModuleClassPermission, self).__init__(**kwargs)
        self.view = kwargs.get('view', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseTargetComparison(Model):
    """PlaceDigestGHGMonthlyResponseTargetComparison.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGMonthlyResponseResults]
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGMonthlyResponseResults]'},
    }

    def __init__(self, *, target_year: int=None, target_label: str=None, results=None, **kwargs) -> None:
        super(PlaceDigestGHGMonthlyResponseTargetComparison, self).__init__(**kwargs)
        self.target_year = target_year
        self.target_label = target_label
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPmProperty(Model):
    """EnergyStarPmProperty.

    :param pm_property_id: The Portfolio Manager property identifier
     null when not linked to a portfolio manager property
    :type pm_property_id: long
    :param pm_property_name: The Portfolio Manager property name
     null when not linked to a portfolio manager property
    :type pm_property_name: str
    :param pm_property_use_type: The Portfolio Manager property use type
     null when not linked to a portfolio manager property
    :type pm_property_use_type: str
    :param pm_floor_area: The Portfolio Manager floor area
     null when not linked to portfolio manager property
    :type pm_floor_area: int
    :param pm_floor_area_units: The Portfolio Manager floor area units
     null when not linked to a portfolio manager property
    :type pm_floor_area_units: str
    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    """

    _attribute_map = {
        'pm_property_id': {'key': 'pmPropertyId', 'type': 'long'},
        'pm_property_name': {'key': 'pmPropertyName', 'type': 'str'},
        'pm_property_use_type': {'key': 'pmPropertyUseType', 'type': 'str'},
        'pm_floor_area': {'key': 'pmFloorArea', 'type': 'int'},
        'pm_floor_area_units': {'key': 'pmFloorAreaUnits', 'type': 'str'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
    }

    def __init__(self, *, pm_property_id: int=None, pm_property_name: str=None, pm_property_use_type: str=None, pm_floor_area: int=None, pm_floor_area_units: str=None, place=None, place_size=None, **kwargs) -> None:
        super(EnergyStarPmProperty, self).__init__(**kwargs)
        self.pm_property_id = pm_property_id
        self.pm_property_name = pm_property_name
        self.pm_property_use_type = pm_property_use_type
        self.pm_floor_area = pm_floor_area
        self.pm_floor_area_units = pm_floor_area_units
        self.place = place
        self.place_size = place_size



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateEstimatedChild(Model):
    """Estimated.

    All required parameters must be populated in order to send to Azure.

    :param estimated:  <span class='property-internal'>Required when Update is
     set to True</span>
    :type estimated: bool
    :param update: Required. Indicates whether or not the header value is
     being updated <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'update': {'required': True},
    }

    _attribute_map = {
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillHeaderUpdateEstimatedChild, self).__init__(**kwargs)
        self.estimated = kwargs.get('estimated', None)
        self.update = kwargs.get('update', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarRatingChild(Model):
    """EnergyStarRatingChild.

    :param rating_date: The date the score was received
    :type rating_date: datetime
    :param calendar_period: The year and month for the ENERGY STAR score
    :type calendar_period: int
    :param rating: The ENERGY STAR score
    :type rating: int
    :param site_energy_use_intensity: The weather-normalized property energy
     use intensity (kBtu/ft²)
    :type site_energy_use_intensity: float
    """

    _attribute_map = {
        'rating_date': {'key': 'ratingDate', 'type': 'iso-8601'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'rating': {'key': 'rating', 'type': 'int'},
        'site_energy_use_intensity': {'key': 'siteEnergyUseIntensity', 'type': 'float'},
    }

    def __init__(self, *, rating_date=None, calendar_period: int=None, rating: int=None, site_energy_use_intensity: float=None, **kwargs) -> None:
        super(EnergyStarRatingChild, self).__init__(**kwargs)
        self.rating_date = rating_date
        self.calendar_period = calendar_period
        self.rating = rating
        self.site_energy_use_intensity = site_energy_use_intensity



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationUpdateRequest(Model):
    """NotificationUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param notification_ids: List of notification ids to perform the action on
     <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type notification_ids: list[long]
    :param action: Required. Action to perform
     Unread marks all notifications in the list as unread
     Read marks all notifications in the list as read
     Archived marks all notifications in the list as archived
     Unarchived marks all notifications in the list as unarchived <span
     class='property-internal'>One of Read, Unread, Archived, Unarchived
     </span> <span class='property-internal'>Required</span>
    :type action: str
    """

    _validation = {
        'action': {'required': True},
    }

    _attribute_map = {
        'notification_ids': {'key': 'notificationIds', 'type': '[long]'},
        'action': {'key': 'action', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(NotificationUpdateRequest, self).__init__(**kwargs)
        self.notification_ids = kwargs.get('notification_ids', None)
        self.action = kwargs.get('action', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFCreate(Model):
    """UDFCreate.

    All required parameters must be populated in order to send to Azure.

    :param udf_type: Required. The UDF type. Possible value include: "Vendor",
     "Place", "Account", "Meter", "ChannelVersion", "Rate", and "Bill" <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type udf_type: str
    :param name: Required. The UDF's name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type name: str
    :param data_type_id: Required. The UDF's data type identifier.
     Possible value include:
     1 (boolean), 2 (integer), 3 (string),
     4 (double), 6 (date), 12 (select list),
     13 (url), 15 (formatted text), 16 (image),
     17 (pdf), 18 (document file), 19 (JSON text) <span
     class='property-internal'>Required</span>
    :type data_type_id: int
    :param display_order: Required. <p>The UDF's display order</p>
     <p>A value of 1 or less will put this record the beginning of the list</p>
     <p>If the display order exists it will put this record at that spot.
     Display orders greater than or equal to this will be incremented by 1</p>
     <p>A value greater than the stored max will put this record at the end of
     the list</p> <span class='property-internal'>Required</span>
    :type display_order: int
    :param udf_select_values: <p>An array of options to populate a UDF select
     list.</p>
     <p>Required when dataTypeId is 12 otherwise this will be ignored.</p>
     <span class='property-internal'>Required when dataTypeId is set to
     12</span>
    :type udf_select_values: list[~energycap.sdk.models.UDFSelectValueCreate]
    """

    _validation = {
        'udf_type': {'required': True, 'max_length': 32, 'min_length': 0},
        'name': {'required': True, 'max_length': 32, 'min_length': 0},
        'data_type_id': {'required': True},
        'display_order': {'required': True},
    }

    _attribute_map = {
        'udf_type': {'key': 'udfType', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'udf_select_values': {'key': 'udfSelectValues', 'type': '[UDFSelectValueCreate]'},
    }

    def __init__(self, **kwargs):
        super(UDFCreate, self).__init__(**kwargs)
        self.udf_type = kwargs.get('udf_type', None)
        self.name = kwargs.get('name', None)
        self.data_type_id = kwargs.get('data_type_id', None)
        self.display_order = kwargs.get('display_order', None)
        self.udf_select_values = kwargs.get('udf_select_values', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListResponseListField(Model):
    """ListResponseListField.

    :param field_id: Column/Filter Identifier
    :type field_id: int
    :param width: Width of the column
    :type width: int
    :param display_order: Order of the column
    :type display_order: int
    :param sortable: Is the column sortable?
    :type sortable: bool
    :param caption: Caption for the column/filter
    :type caption: str
    :param sort_direction: Sort direction "asc" or "desc"
    :type sort_direction: str
    :param sort_order: Sort order for the column
    :type sort_order: int
    :param data_type_code: Type of Data in this column
    :type data_type_code: str
    :param required_output: Is this column a required column?
    :type required_output: bool
    :param visible: Is this column currently visible?
    :type visible: bool
    """

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'sortable': {'key': 'sortable', 'type': 'bool'},
        'caption': {'key': 'caption', 'type': 'str'},
        'sort_direction': {'key': 'sortDirection', 'type': 'str'},
        'sort_order': {'key': 'sortOrder', 'type': 'int'},
        'data_type_code': {'key': 'dataTypeCode', 'type': 'str'},
        'required_output': {'key': 'requiredOutput', 'type': 'bool'},
        'visible': {'key': 'visible', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ListResponseListField, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.width = kwargs.get('width', None)
        self.display_order = kwargs.get('display_order', None)
        self.sortable = kwargs.get('sortable', None)
        self.caption = kwargs.get('caption', None)
        self.sort_direction = kwargs.get('sort_direction', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.data_type_code = kwargs.get('data_type_code', None)
        self.required_output = kwargs.get('required_output', None)
        self.visible = kwargs.get('visible', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountResponse(Model):
    """AccountResponse.

    :param account_id: The account identifier
    :type account_id: int
    :param account_meter_id: The accountmeter identifier for the account
    :type account_meter_id: int
    :param account_code: The account code
    :type account_code: str
    :param account_info: The account info
    :type account_info: str
    :param account_type:
    :type account_type: ~energycap.sdk.models.AccountTypeChild
    :param cost_center:
    :type cost_center: ~energycap.sdk.models.CostCenterChild
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param contact:
    :type contact: ~energycap.sdk.models.ContactChild
    :param customer:
    :type customer: ~energycap.sdk.models.CustomerChild
    :param active: Indicates whether the Account is active or inactive
    :type active: bool
    :param accrual_enabled: Indicates if this account is used with accruals
    :type accrual_enabled: bool
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param deposit_paid: The date and time a deposit was paid
    :type deposit_paid: datetime
    :param deposit_return: The date and time the account deposit was returned
    :type deposit_return: datetime
    :param deposit_note: A note related to the account deposit
    :type deposit_note: str
    :param deposit_amount: The account deposit amount
    :type deposit_amount: float
    :param memo: The account memo
    :type memo: str
    :param service_start: The account's service begin date and time
    :type service_start: datetime
    :param service_end: The account's service end date and time
    :type service_end: datetime
    :param account_general_ledger:
    :type account_general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    :param meters: An array of identifiers for meters attached to this account
    :type meters:
     list[~energycap.sdk.models.AccountMeterChildWithSerialNumber]
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the account was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification
    :type modified_date: datetime
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param has_calculated_meter: Indicates whether the Account has a child
     calculated meter
    :type has_calculated_meter: bool
    :param has_split_parent_meter: Indicates whether the Account is a
     recipient of a split
    :type has_split_parent_meter: bool
    :param has_split_child_meter: Indicates whether the Account has a child
     split meter
    :type has_split_child_meter: bool
    :param account_code_history:
    :type account_code_history: ~energycap.sdk.models.AccountCodeHistoryChild
    :param account_description: A description of the account
    :type account_description: str
    :param audit_enabled: When true, bills for this account will be audited
    :type audit_enabled: bool
    :param data_access_release_id: The data access release identifier for this
     Account, null if there is no release.
    :type data_access_release_id: int
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_type': {'key': 'accountType', 'type': 'AccountTypeChild'},
        'cost_center': {'key': 'costCenter', 'type': 'CostCenterChild'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'contact': {'key': 'contact', 'type': 'ContactChild'},
        'customer': {'key': 'customer', 'type': 'CustomerChild'},
        'active': {'key': 'active', 'type': 'bool'},
        'accrual_enabled': {'key': 'accrualEnabled', 'type': 'bool'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'deposit_paid': {'key': 'depositPaid', 'type': 'iso-8601'},
        'deposit_return': {'key': 'depositReturn', 'type': 'iso-8601'},
        'deposit_note': {'key': 'depositNote', 'type': 'str'},
        'deposit_amount': {'key': 'depositAmount', 'type': 'float'},
        'memo': {'key': 'memo', 'type': 'str'},
        'service_start': {'key': 'serviceStart', 'type': 'iso-8601'},
        'service_end': {'key': 'serviceEnd', 'type': 'iso-8601'},
        'account_general_ledger': {'key': 'accountGeneralLedger', 'type': 'GeneralLedgerChild'},
        'meters': {'key': 'meters', 'type': '[AccountMeterChildWithSerialNumber]'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'has_calculated_meter': {'key': 'hasCalculatedMeter', 'type': 'bool'},
        'has_split_parent_meter': {'key': 'hasSplitParentMeter', 'type': 'bool'},
        'has_split_child_meter': {'key': 'hasSplitChildMeter', 'type': 'bool'},
        'account_code_history': {'key': 'accountCodeHistory', 'type': 'AccountCodeHistoryChild'},
        'account_description': {'key': 'accountDescription', 'type': 'str'},
        'audit_enabled': {'key': 'auditEnabled', 'type': 'bool'},
        'data_access_release_id': {'key': 'dataAccessReleaseId', 'type': 'int'},
    }

    def __init__(self, *, account_id: int=None, account_meter_id: int=None, account_code: str=None, account_info: str=None, account_type=None, cost_center=None, vendor=None, contact=None, customer=None, active: bool=None, accrual_enabled: bool=None, address=None, deposit_paid=None, deposit_return=None, deposit_note: str=None, deposit_amount: float=None, memo: str=None, service_start=None, service_end=None, account_general_ledger=None, meters=None, created_by=None, created_date=None, modified_by=None, modified_date=None, cost_unit=None, has_calculated_meter: bool=None, has_split_parent_meter: bool=None, has_split_child_meter: bool=None, account_code_history=None, account_description: str=None, audit_enabled: bool=None, data_access_release_id: int=None, **kwargs) -> None:
        super(AccountResponse, self).__init__(**kwargs)
        self.account_id = account_id
        self.account_meter_id = account_meter_id
        self.account_code = account_code
        self.account_info = account_info
        self.account_type = account_type
        self.cost_center = cost_center
        self.vendor = vendor
        self.contact = contact
        self.customer = customer
        self.active = active
        self.accrual_enabled = accrual_enabled
        self.address = address
        self.deposit_paid = deposit_paid
        self.deposit_return = deposit_return
        self.deposit_note = deposit_note
        self.deposit_amount = deposit_amount
        self.memo = memo
        self.service_start = service_start
        self.service_end = service_end
        self.account_general_ledger = account_general_ledger
        self.meters = meters
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.cost_unit = cost_unit
        self.has_calculated_meter = has_calculated_meter
        self.has_split_parent_meter = has_split_parent_meter
        self.has_split_child_meter = has_split_child_meter
        self.account_code_history = account_code_history
        self.account_description = account_description
        self.audit_enabled = audit_enabled
        self.data_access_release_id = data_access_release_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculationRequest(Model):
    """Adding/subtracting calculation involving meters and/or meter groups
    You must pass in at least 1 thing to sum or subtract.

    :param sum:
    :type sum: ~energycap.sdk.models.SumRequest
    :param subtract:
    :type subtract: ~energycap.sdk.models.SubtractRequest
    """

    _attribute_map = {
        'sum': {'key': 'sum', 'type': 'SumRequest'},
        'subtract': {'key': 'subtract', 'type': 'SubtractRequest'},
    }

    def __init__(self, *, sum=None, subtract=None, **kwargs) -> None:
        super(CalculationRequest, self).__init__(**kwargs)
        self.sum = sum
        self.subtract = subtract



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountAuditEnable(Model):
    """AccountAuditEnable.

    :param account_ids: List of AccountIds to try and update <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type account_ids: list[int]
    :param audit_enabled: True to allow the accounts' bills to be audited
     False to exclude the accounts' bills from being audited <span
     class='property-internal'>Required (defined)</span>
    :type audit_enabled: bool
    """

    _attribute_map = {
        'account_ids': {'key': 'accountIds', 'type': '[int]'},
        'audit_enabled': {'key': 'auditEnabled', 'type': 'bool'},
    }

    def __init__(self, *, account_ids=None, audit_enabled: bool=None, **kwargs) -> None:
        super(AccountAuditEnable, self).__init__(**kwargs)
        self.account_ids = account_ids
        self.audit_enabled = audit_enabled



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostAvoidanceTask(Model):
    """CostAvoidanceTask.

    :param has_attachments: Indicates whether or not the task has an output
     log available for download
    :type has_attachments: bool
    :param cost_avoidance_task_id: The task ID
    :type cost_avoidance_task_id: int
    :param task_gu_id: The task GUID
    :type task_gu_id: str
    :param task_type:
    :type task_type: ~energycap.sdk.models.TaskType
    :param begin_date: The date and time the task began
    :type begin_date: datetime
    :param end_date: The date and time the task finished. If the task is not
     finished, endDate will have no value
    :type end_date: datetime
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param settings:
    :type settings: ~energycap.sdk.models.CostAvoidanceSettings
    :param filters: The task's filters
    :type filters: list[~energycap.sdk.models.FilterResponse]
    :param message: If there was a catastrophic error during task processing,
     it will go here
    :type message: str
    :param reason: The reason for the cost avoidance task. Will be one of the
     following:
     * ResetBaseline
     * SavedAndReprocessedMeter
     * ProcessSavings
     * SpecialAdjustmentAddedEditedRemoved
     * SpecialAdjustmentAddedEditedRemovedSetupSheet
     * MeterCostAvoidanceSettingsGloballyUpdated
     * AucRangeModified
     * OtherSavingsAddedEdited
     * OtherSavingsAddedEditedSetupSheet
    :type reason: str
    :param status: The status of the cost avoidance task. Will be one of the
     following:
     * Processing
     * Complete
     * Error
    :type status: str
    :param task_note: Notes added to the cost avoidance task by the user
    :type task_note: str
    :param baseline_log:
    :type baseline_log: ~energycap.sdk.models.BaselineLog
    :param savings_log:
    :type savings_log: ~energycap.sdk.models.SavingsLog
    """

    _attribute_map = {
        'has_attachments': {'key': 'hasAttachments', 'type': 'bool'},
        'cost_avoidance_task_id': {'key': 'costAvoidanceTaskId', 'type': 'int'},
        'task_gu_id': {'key': 'taskGUId', 'type': 'str'},
        'task_type': {'key': 'taskType', 'type': 'TaskType'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'settings': {'key': 'settings', 'type': 'CostAvoidanceSettings'},
        'filters': {'key': 'filters', 'type': '[FilterResponse]'},
        'message': {'key': 'message', 'type': 'str'},
        'reason': {'key': 'reason', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'task_note': {'key': 'taskNote', 'type': 'str'},
        'baseline_log': {'key': 'baselineLog', 'type': 'BaselineLog'},
        'savings_log': {'key': 'savingsLog', 'type': 'SavingsLog'},
    }

    def __init__(self, *, has_attachments: bool=None, cost_avoidance_task_id: int=None, task_gu_id: str=None, task_type=None, begin_date=None, end_date=None, user=None, settings=None, filters=None, message: str=None, reason: str=None, status: str=None, task_note: str=None, baseline_log=None, savings_log=None, **kwargs) -> None:
        super(CostAvoidanceTask, self).__init__(**kwargs)
        self.has_attachments = has_attachments
        self.cost_avoidance_task_id = cost_avoidance_task_id
        self.task_gu_id = task_gu_id
        self.task_type = task_type
        self.begin_date = begin_date
        self.end_date = end_date
        self.user = user
        self.settings = settings
        self.filters = filters
        self.message = message
        self.reason = reason
        self.status = status
        self.task_note = task_note
        self.baseline_log = baseline_log
        self.savings_log = savings_log



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitType(Model):
    """UnitType.

    :param unit_type_id:
    :type unit_type_id: int
    :param unit_type_code:
    :type unit_type_code: str
    :param unit_type_info:
    :type unit_type_info: str
    """

    _attribute_map = {
        'unit_type_id': {'key': 'unitTypeId', 'type': 'int'},
        'unit_type_code': {'key': 'unitTypeCode', 'type': 'str'},
        'unit_type_info': {'key': 'unitTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UnitType, self).__init__(**kwargs)
        self.unit_type_id = kwargs.get('unit_type_id', None)
        self.unit_type_code = kwargs.get('unit_type_code', None)
        self.unit_type_info = kwargs.get('unit_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseGHGScope(Model):
    """PlaceDigestGHGMonthlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGMonthlyResponseTargetComparison
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGMonthlyResponseResults]
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGMonthlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGMonthlyResponseResults]'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestGHGMonthlyResponseGHGScope, self).__init__(**kwargs)
        self.ghg_scope_id = kwargs.get('ghg_scope_id', None)
        self.ghg_scope_code = kwargs.get('ghg_scope_code', None)
        self.ghg_scope_info = kwargs.get('ghg_scope_info', None)
        self.target_comparison = kwargs.get('target_comparison', None)
        self.results = kwargs.get('results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OtherSavingsCategoryRequest(Model):
    """OtherSavingsCategoryRequest.

    :param other_savings_category_info: Other savings category name
    :type other_savings_category_info: str
    """

    _attribute_map = {
        'other_savings_category_info': {'key': 'otherSavingsCategoryInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(OtherSavingsCategoryRequest, self).__init__(**kwargs)
        self.other_savings_category_info = kwargs.get('other_savings_category_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdjustmentBaseMethodChild(Model):
    """AdjustmentBaseMethodChild.

    :param special_adjustment_method_id: Special adjustment method identifier
    :type special_adjustment_method_id: int
    :param label: Special adjustment method description
    :type label: str
    """

    _attribute_map = {
        'special_adjustment_method_id': {'key': 'specialAdjustmentMethodId', 'type': 'int'},
        'label': {'key': 'label', 'type': 'str'},
    }

    def __init__(self, *, special_adjustment_method_id: int=None, label: str=None, **kwargs) -> None:
        super(AdjustmentBaseMethodChild, self).__init__(**kwargs)
        self.special_adjustment_method_id = special_adjustment_method_id
        self.label = label
